# Spring Force Tool

Description. 
The package spring force is used to:
	- Find solutions of a force in Hooke's Law (F = -kx)
	- Find the Energy Solution for s spring in Hooke's Law
	- Find solutions of a Mechanical Harmonic Oscillator
	- Plot the function of force F(x) in Hooke's Law
	- Plot the function of a Harmonic oscillator as X(t)
	- Plot the function of Energy U(x) in Hooke's Law
	- Save image

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install spring_force
```

## Author
Egleidson Frederik

## License
Not needed